@@ -15,6 +15,8 @@ django_sso_app_profile_urlpatterns = [
          name='profile'),
     path('profile/update/', RedirectView.as_view(url=app_settings.REMOTE_PROFILE_UPDATE_URL, permanent=False),
          name='profile.update'),
+    path('profile/complete/', RedirectView.as_view(url=app_settings.REMOTE_PROFILE_COMPLETE_URL, permanent=False),
+         name='profile.complete'),
 ]
 
 django_sso_app_i18n_urlpatterns = django_sso_app_profile_urlpatterns
