@@ -205,6 +205,8 @@ AUTH_PASSWORD_VALIDATORS = [
 # https://docs.djangoproject.com/en/dev/ref/settings/#middleware
 MIDDLEWARE = [
     "django_sso_app.core.middleware.x_forwarded_for.XForwardedForMiddleware",  # django-sso-app
+    # "django_sso_app.core.middleware.same_site.SameSiteMiddleware",  # django-sso-app
+
     "django.middleware.security.SecurityMiddleware",
     "corsheaders.middleware.CorsMiddleware",  # pai
     "django.contrib.sessions.middleware.SessionMiddleware",
@@ -334,16 +336,15 @@ ACCOUNT_DEFAULT_HTTP_PROTOCOL = env("ACCOUNT_DEFAULT_HTTP_PROTOCOL", default="ht
 # CSRF
 if DEBUG:
     CSRF_COOKIE_DOMAIN = None
-    CORS_ORIGIN_ALLOW_ALL = True
     CSRF_TRUSTED_ORIGINS = []
-else:
-    CSRF_COOKIE_DOMAIN = COOKIE_DOMAIN
-    CSRF_TRUSTED_ORIGINS = ['.{0}'.format(COOKIE_DOMAIN)]
+#else:
+#    CSRF_COOKIE_DOMAIN = COOKIE_DOMAIN
+#    CSRF_TRUSTED_ORIGINS = ['.{0}'.format(COOKIE_DOMAIN)]
 
 # cors
 if DEBUG:
-    """CORS_ORIGIN_ALLOW_ALL = True"""
-    CORS_ORIGINS = ['localhost:8000', 'localhost:6060', 'bs-local.com:8000']
+    CORS_ORIGIN_ALLOW_ALL = True
+    CORS_ORIGINS = ['localhost:8000', 'localhost:8001', 'localhost:6060', 'bs-local.com:8000']
     CORS_ALLOW_CREDENTIALS = True
 else:
     # https://github.com/ottoyiu/django-cors-headers
