@@ -11,7 +11,7 @@ SECRET_KEY = env(
     default="7MA0D3xJcONLvhB2ymIgkpc9Rulc9nt3hLStawwMZVAm6rfmW3wuoZvp2efwcfsy",
 )
 # https://docs.djangoproject.com/en/dev/ref/settings/#allowed-hosts
-ALLOWED_HOSTS = ["localhost", "0.0.0.0", "127.0.0.1", COOKIE_DOMAIN]  #!
+ALLOWED_HOSTS = ["localhost", "0.0.0.0", "127.0.0.1", COOKIE_DOMAIN, 'bs-local.com']  #!
 
 # CACHES
 # ------------------------------------------------------------------------------
