@@ -20,8 +20,8 @@ from allauth.account.adapter import DefaultAccountAdapter
 from allauth.account import app_settings as allauth_app_settings
 
 from .mixins import TryAuthenticateMixin
-from .utils import set_session_key, check_user_can_login
-from .exceptions import UnsubscribedUserException, DjangoStaffUsersCanNotLoginException  #, DectivatedUserException
+from .utils import set_session_key, check_user_can_login, invalidate_cookie
+from .exceptions import UnsubscribedUserException, DjangoStaffUsersCanNotLoginException, ProfileIncompleteException  #, DectivatedUserException
 from .apps.emails.models import EmailAddress
 from .apps.devices.models import Device
 from .apps.devices.utils import get_request_device
@@ -43,6 +43,10 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
         self.error_messages = DefaultAccountAdapter.error_messages
         self.error_messages['email_not_verified'] = _('We have sent an e-mail to you for verification. Follow the link provided to finalize the signup process. Please contact us if you do not receive it within a few minutes.')
 
+    def populate_username(self, request, user):
+        # new user has username == email
+        user.username = user.email
+
     def is_open_for_signup(self, request):
         """
         Checks whether or not the site is open for signups.
@@ -93,7 +97,7 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
         # check_user_can_login(user)
 
         if not hasattr(user, 'backend'):
-            from .backends import DjangoSsoAppLoginAuthenticationBackend
+            from .authentication.backends.login import DjangoSsoAppLoginAuthenticationBackend
             backends = get_backends()
             backend = None
             for b in backends:
@@ -134,7 +138,8 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
             request_device = get_request_device(request)
 
         except Exception as e:
-            logger.debug('no device on request because of "{}"'.format(e))
+            logger.warning('No device on request because of "{}"'.format(e))
+            request_device = None
 
         logging_out_user = request.user
 
@@ -145,12 +150,21 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
             if app_settings.LOGOUT_DELETES_ALL_PROFILE_DEVICES:
                 deleted_devices = self.remove_all_user_profile_devices(logging_out_user)
             else:
-                deleted_devices = self.remove_user_profile_device(request_device)
+                if request_device is not None:
+                    deleted_devices = self.remove_user_profile_device(request_device)
+                else:
+                    deleted_devices = 0
 
             logger.info('({}) devices deleted for user "{}"'.format(deleted_devices, logging_out_user))
 
     def confirm_email(self, request, email_address):
-        super(AccountAdapter, self).confirm_email(request, email_address)
+        """
+        Marks the email address as confirmed on the db,
+        deletes old user emails.
+        """
+        email_address.verified = True
+        email_address.set_as_primary(conditional=False)
+        email_address.save()
 
         # one email per user
         email_address.user.emailaddress_set.exclude(email=email_address).delete()
@@ -164,7 +178,7 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
         #exceptions print(inspect.stack()[1].function)
 
         """Only authenticates, does not actually login. See `login`"""
-        from .backends import DjangoSsoAppLoginAuthenticationBackend
+        from .authentication.backends.login import DjangoSsoAppLoginAuthenticationBackend
 
         self.pre_authenticate(request, **credentials)
 
@@ -184,7 +198,7 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
         authentication_success = False
 
         try:
-            check_user_can_login(user)
+            check_user_can_login(user, skip_profile_checks=True)
 
         except UnsubscribedUserException:
             user_unsubscribed_at = user.sso_app_profile.unsubscribed_at
@@ -268,15 +282,20 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
         return EmailAddress.objects.filter(user=user,
                                            verified=True).update(verified=False)
 
-    def add_user_profile_device(self, user, fingerprint, user_agent=None):
+    def add_user_profile_device(self, user, fingerprint, secret=None):
         profile = user.sso_app_profile
-        logger.info(
-            'Adding User Device for profile "{}" with fingerprint "{}"'.format(profile,
-                                                                               fingerprint))
+        secret = secret or app_settings.TOKENS_JWT_SECRET
 
-        device = Device.objects.create(profile=profile, fingerprint=fingerprint)
-        logger.debug('device "{}" created with key "{}" and fingerprint "{}"'.format(device,
+        logger.info(
+            'Adding User Device for profile "{}" with fingerprint "{}" and secret "{}"'.format(profile,
+                                                                                               fingerprint,
+                                                                                               secret))
+
+        device = Device.objects.create(profile=profile, fingerprint=fingerprint, apigw_jwt_secret=secret)
+
+        logger.debug('device "{}" created with key "{}" secret "{}" and fingerprint "{}"'.format(device,
                                                                                      device.apigw_jwt_key,
+                                                                                     device.apigw_jwt_secret,
                                                                                      device.fingerprint))
 
         return device
@@ -375,10 +394,32 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
 
             raise SuspiciousOperation(_msg)
 
+    def update_user_email(self, user, new_email):
+        user.email = new_email  # set user model email
+
+        setattr(user, '__dssoa__email_updated', True)
+
+        user.save()
+
+    def update_user_username(self, user, new_username):
+        user.username = new_username # set user model username
+
+        setattr(user, '__dssoa__username_updated', True)
+
+        user.save()
+
+    def try_disable_response_jwt(self, user, response):
+        if self.request is None:
+            raise KeyError('no request object')
+
+        invalidate_cookie(response, app_settings.JWT_COOKIE_NAME)
+
     def try_update_response_jwt(self, user, response):
         if self.request is None:
             raise KeyError('no request object')
 
+        logger.info('Updating resopnse jwt for "{}"'.format(user))
+
         requesting_user = self.request.user
 
         if not is_django_staff(requesting_user):
@@ -403,7 +444,5 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
                     raise SuspiciousOperation(_msg)
 
         else:
-            _msg = 'User "{}" tried to updated profile for "{}"'.format(requesting_user, user)
-            logger.warning(_msg)
-
-            raise SuspiciousOperation(_msg)
+            _msg = 'Admin user "{}" updated profile for "{}", skipping jwt update'.format(requesting_user, user)
+            logger.info(_msg)
