@@ -10,6 +10,7 @@ from allauth.account import app_settings as allauth_settings
 from allauth.utils import get_username_max_length
 
 from ..apps.emails.models import EmailAddress
+from ..apps.groups.models import Group
 from ..forms import LoginForm, SignupForm
 from .. import app_settings
 
@@ -46,7 +47,11 @@ class BaseSignupSerializer(serializers.Serializer):
     password1 = serializers.CharField(write_only=True)
     password2 = serializers.CharField(write_only=True)
 
-    referrer = serializers.CharField(required=False)
+    referer = serializers.CharField(required=False)
+
+    fingerprint = serializers.CharField(required=False)
+
+    groups = serializers.ListField(child=serializers.CharField(), required=False)
 
 
 if app_settings.BACKEND_SIGNUP_MUST_FILL_PROFILE:
@@ -72,6 +77,8 @@ if app_settings.BACKEND_SIGNUP_MUST_FILL_PROFILE:
 
         language = serializers.CharField(required='language' in app_settings.REQUIRED_PROFILE_FIELDS, allow_null=True)
 
+        alias = serializers.CharField(required='alias' in app_settings.REQUIRED_PROFILE_FIELDS, allow_null=True)
+
 else:
     class SignupSerializer(BaseSignupSerializer):
         pass
@@ -96,6 +103,7 @@ class PasswordResetSerializer(serializers.Serializer):
         activate_translation(user_language)
 
         return value
+
 """
     def get_email_options(self):
         # Override this method to change default e-mail options
@@ -113,9 +121,22 @@ class PasswordResetSerializer(serializers.Serializer):
 
 
 class PasswordResetFromKeySerializer(serializers.Serializer):
+    uidb36 = serializers.CharField()
+    key = serializers.CharField()
     password1 = serializers.CharField()
     password2 = serializers.CharField()
 
 
-class EmailUpdateSerializer(serializers.Serializer):
-    email = serializers.CharField()
+class AddEmailSerializer(serializers.Serializer):
+    email = serializers.EmailField()
+
+
+class PasswordChangeSerializer(serializers.Serializer):
+    oldpassword = serializers.CharField()
+    password1 = serializers.CharField()
+    password2 = serializers.CharField()
+
+
+class PasswordSetSerializer(serializers.Serializer):
+    password1 = serializers.CharField()
+    password2 = serializers.CharField()
