@@ -344,6 +344,10 @@ class AppSettings(object):
     def USER_TYPES(self):
         return self._setting('USER_TYPES', [], list)
 
+    @property
+    def SAME_SITE_COOKIE_NONE(self):
+        return self._setting('SAME_SITE_COOKIE_NONE', False, bool)
+
 
 # Ugly? Pennersr says Guido recommends this himself ...
 # http://mail.python.org/pipermail/python-ideas/2012-May/014969.html
