@@ -13,7 +13,8 @@ from ...devices.models import Device
 from ...groups.models import Group
 from ...profiles.models import Profile
 from ..utils import delete_apigw_consumer, create_apigw_consumer_jwt, delete_apigw_consumer_jwt, \
-                    create_apigw_consumer_acl, delete_apigw_consumer_acl, get_profile_apigw_consumer_id
+                    create_apigw_consumer_acl, delete_apigw_consumer_acl, get_profile_apigw_consumer_id, \
+                    get_apigw_consumer_acls
 
 logger = logging.getLogger('django_sso_app.core.apps.api_gateway')
 
@@ -100,13 +101,20 @@ def signal_handler_when_profile_is_added_to_or_removed_from_group(action, instan
 
         if not is_django_staff(user):
             if action == 'pre_add':
+
+                # do not create acl groups for signing up users
+                if user.last_login is None:
+                    logger.info('do not create acl groups while user never logged in')
+                    return
+
                 for pk in pk_set:
                     group = Group.objects.get(id=pk)
+
                     logger.info('creating api gateway acl group "{}" for profile "{}"'.format(group, profile))
 
                     status_code, resp = create_apigw_consumer_acl(profile, group.name)
 
-                    if status_code == 201:
+                    if status_code < 400:
                         logger.info('api gateway acl group created {}, {}'.format(status_code, resp))
 
                         if not is_loaddata:
@@ -121,13 +129,13 @@ def signal_handler_when_profile_is_added_to_or_removed_from_group(action, instan
 
                     status_code, resp = delete_apigw_consumer_acl(profile, group.name)
 
-                    if status_code == 200:
+                    if status_code < 400:
                         logger.info('"{}" DELETED, updating profile sso_rev'.format(group))
 
                         if not is_loaddata:
                             profile.update_rev(True)
                     else:
-                        logger.exception('error ({}) creating api gateway acl group'.format(status_code))
+                        logger.exception('error ({}) deleting api gateway acl group'.format(status_code))
 
 
 @receiver(user_logged_in)
@@ -141,12 +149,15 @@ def post_user_login(**kwargs):
         apigateway_consumer_id = get_profile_apigw_consumer_id(profile)
         logger.info('apigateway_consumer_id on login "{}"'.format(apigateway_consumer_id))
 
-        for group in profile.groups.all():
+        _status, apigateway_acl_response = get_apigw_consumer_acls(profile)
+        actual_acl_groups = list(map(lambda x: x['group'], apigateway_acl_response['data']))
+
+        for group in profile.groups.exclude(name__in=actual_acl_groups):
             # try create apigw consumer acls for logged in user
-            
+
             status_code, resp = create_apigw_consumer_acl(profile, group.name)
 
-            if status_code == 201:
+            if status_code < 400:
                 logger.info('apigateway acl group "{}" created on login'.format(group.name))
 
             else:
