@@ -57,20 +57,25 @@ class DjangoSsoAppUserModelMixin(object):
     def password_has_been_hardened(self):
         has_password = getattr(self, '__dssoa__old_password', self.password) not in [None, '']
 
-        if has_password:
-            old_hashed_password = getattr(self, '__dssoa__old_password')
-            old_hasher = identify_hasher(old_hashed_password)
-            new_hashed_password = self.password
-            new_hasher = identify_hasher(new_hashed_password)
+        try:
+            if has_password:
+                old_hashed_password = getattr(self, '__dssoa__old_password')
+                old_hasher = identify_hasher(old_hashed_password)
+                new_hashed_password = self.password
+                new_hasher = identify_hasher(new_hashed_password)
 
-            try:
-                hasher = get_hasher('default')
-                return hasher.must_update(old_hashed_password)
+                try:
+                    hasher = get_hasher('default')
+                    return hasher.must_update(old_hashed_password)
 
-            except AssertionError:
-                logger.exception('Error checking password hardened')
-                return old_hasher != new_hasher
-        else:
+                except AssertionError:
+                    logger.exception('Error checking password hardened')
+                    return old_hasher != new_hasher
+            else:
+                return False
+
+        except Exception:
+            logger.exception('Exception on checking password hardened')
             return False
 
     def __init__(self, *args, **kwargs):
