@@ -5,12 +5,14 @@ from django.contrib.auth import get_user_model
 from django.db import IntegrityError
 from django.forms import ValidationError
 from django.http import Http404
-from django.utils.decorators import method_decorator
+# from django.utils.decorators import method_decorator
 from django.utils.translation import ugettext_lazy as _
-from django.views.decorators.cache import cache_page
-from django.db.models import Q
+# from django.views.decorators.cache import cache_page
+# from django.db.models import Q
 from django.core.exceptions import SuspiciousOperation
 
+from django_filters.rest_framework import DjangoFilterBackend
+
 from allauth.account.adapter import get_adapter
 from allauth.account.utils import filter_users_by_username, filter_users_by_email
 
@@ -28,9 +30,10 @@ from .serializers import (CheckUserExistenceSerializer,
 
 from ...apps.emails.models import EmailAddress
 from ...permissions import StaffPermission
-from ...permissions import is_staff
+from ...permissions import is_staff, is_django_staff
 from ...utils import is_test_user, invalidate_cookie, get_session_key
 from ... import app_settings
+from .filters import UserFilter
 
 User = get_user_model()
 
@@ -41,18 +44,20 @@ class CheckUserExistenceApiView(APIView):
     """
     Retrieve a "condensed" user instance {"id": ".."} by either "username" or "email" as query params.
     """
+
     permission_classes = (permissions.AllowAny, )
 
     def get_object(self, login=None, username=None, email=None):
         try:
             if login is not None:
-                user = User.objects.filter(Q(username=login) | Q(email=login)).first()
-                if user is not None:
-                    return user
+                #! NOQA
+                email_users = filter_users_by_email(login)
+                if len(email_users):
+                    return email_users[0]
 
-                email_address = EmailAddress.objects.filter(email=login, verified=True).first()
-                if email_address is not None:
-                    return email_address.user
+                username_users = filter_users_by_username(login)
+                if len(username_users):
+                    return username_users[0]
 
             elif username is None and email is not None:
                 users = filter_users_by_email(email)
@@ -99,6 +104,9 @@ class UserApiViewSet(mixins.ListModelMixin,
 
     lookup_field = 'sso_app_profile__sso_id'
     # serializer_class = UserSerializer
+    permission_classes = (permissions.IsAuthenticated,)
+    filter_backends = (DjangoFilterBackend,)
+    filter_class = UserFilter
 
     def get_serializer_class(self):
         if self.request.method == 'POST':
@@ -140,12 +148,19 @@ class UserApiViewSet(mixins.ListModelMixin,
         """
         logger.info('Creating user')
 
+        if not is_staff(request.user):
+            msg = 'Non staff user "{}" tried to create new user'.format(request.user)
+            logger.warning(msg)
+
+            raise(SuspiciousOperation(msg))
+
         return super(UserApiViewSet, self).create(request, *args, **kwargs)
 
     def partial_update(self, request, sso_id, *args, **kwargs):
         logger.info('Updating user')
 
         try:
+            user = self.get_object()
             response = super(UserApiViewSet, self).partial_update(request, sso_id, *args, **kwargs)
 
         except (IntegrityError, ValidationError) as e:
@@ -153,30 +168,23 @@ class UserApiViewSet(mixins.ListModelMixin,
 
             logger.info('User {0} tried to update email with already registered one'.format(request.user))
 
-            return Response(_('Email already registered.'), status=status.HTTP_409_CONFLICT)
+            response = Response(_('Email already registered.'), status=status.HTTP_409_CONFLICT)
 
         response_status_code = response.status_code
-        logger.info('Partial_update status code is {}, {}'.format(response_status_code, request.data))
+        logger.debug('Partial_update status code is {}, {}'.format(response_status_code, request.data))
 
         if response_status_code == 200:
             adapter = get_adapter(request)
-            user = self.get_object()
             requesting_user = request.user
+            is_same_user = requesting_user == user
 
-            if get_session_key(request, '__dssoa__user_email_updated', False):
-                is_same_user = requesting_user == user
+            if is_same_user and not is_django_staff(requesting_user):
 
-                if is_same_user:
-                    # loggin out after email update
-                    adapter.logout(request)
+                # must login again if password updated
+                if get_session_key(request, '__dssoa__user_password_updated', False):
+                    invalidate_cookie(response, app_settings.JWT_COOKIE_NAME)
                 else:
-                    if not is_staff(requesting_user):
-                        _msg = 'User "{}" tried to updated email for "{}"'.format(requesting_user, user)
-                        logger.warning(_msg)
-
-                        raise SuspiciousOperation(_msg)
-            else:
-                adapter.try_update_response_jwt(user, response)
+                    adapter.try_update_response_jwt(user, response)
 
         return response
 
@@ -207,27 +215,29 @@ class UserApiViewSet(mixins.ListModelMixin,
         return response
 
 
-class UserRevisionsApiView(generics.ListAPIView):
+class UserRevisionsApiView(mixins.ListModelMixin,
+                           viewsets.GenericViewSet):
     """
     User revisions entrypoint
     """
 
-    queryset = User.objects.filter(is_superuser=False, is_staff=False)
+    queryset = User.objects.filter(is_superuser=False, is_staff=False).order_by('id')
     serializer_class = UserRevisionSerializer
     permission_classes = (StaffPermission,)
 
-    @method_decorator(cache_page(120))
-    def list(self, request):
-        # Note the use of `get_queryset()` instead of `self.queryset`
-        queryset = self.get_queryset()
-        serializer = self.serializer_class(queryset, many=True)
-        return Response(serializer.data)
+    def list(self, request, *args, **kwargs):
+        """
+        List users revisions
+        """
+        logger.info('List users revisions')
+        return super(UserRevisionsApiView, self).list(request, *args, **kwargs)
 
 
 class UserDetailApiView(generics.RetrieveAPIView):
     """
     User detail entrypoint
     """
+
     serializer_class = UserSerializer
 
     def get_queryset(self):
